@@ -92,7 +92,7 @@ def input_options(prompt, default, options, num_accept=False, required=False):
         opt_string = ''
     adjust_prompt = prompt + '(required)' if required else prompt
     if not required and default != '':
-        adjust_prompt += '(default: "' + default + '")'
+        adjust_prompt += '(default: "' + str(default) + '")'
     opt_string = '[' + opt_string + ']' if not opt_string == '' else ''
     r_input = input_raw_input(adjust_prompt + opt_string)
     if r_input == '':
@@ -295,7 +295,7 @@ class CreateMo(object):
         self.apic_login()
 
     def run_wizard_mode(self):
-        if os.uname()[1] != 'BONHUAN-M-D8911':
+        if os.uname()[1] != 'BONHUAN-M-D891':
             self.args = {
                 'host': input_raw_input("Host Name", required=True),
                 'user': input_raw_input("User Name", required=True),
@@ -335,6 +335,12 @@ class CreateMo(object):
             self.mo = temp_mo
         return temp_mo
 
+    def look_up_class(self, class_name, set_mo=True, parentDn=None, propFilter=None):
+        mo = self.modir.lookupByClass(class_name, parentDn=parentDn, propFilter=propFilter)
+        if set_mo:
+            self.mo = mo
+        return mo
+
     def check_if_tenant_exist(self, return_boolean=False, set_mo=True):
         """
         :param return_boolean: if set, return value is True or False
